# coding: utf-8

"""
    Veeroute.Account

    Veeroute Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.10.176203
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.trace_data import TraceData  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestTraceData(unittest.TestCase):
    """TraceData unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TraceData
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.trace_data.TraceData()  # noqa: E501
        if include_optional :
            return TraceData(
                code = 'client_server_service_time_uuid', 
                client = 'client_name', 
                server = 'server_name', 
                service = 'LASTMILE', 
                method = 'PLAN', 
                time = '2021-02-21T09:30+03:00'
            )
        else :
            return TraceData(
                code = 'client_server_service_time_uuid',
        )

    def testTraceData(self):
        """Test TraceData"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Veeroute.Account

    Veeroute Account Panel  # noqa: E501

    The version of the OpenAPI document: 3.10.176203
    Contact: support@veeroute.com
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import vrt_lss_account
from vrt_lss_account.models.user_audit_result import UserAuditResult  # noqa: E501
from vrt_lss_account.rest import ApiException

class TestUserAuditResult(unittest.TestCase):
    """UserAuditResult unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test UserAuditResult
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = vrt_lss_account.models.user_audit_result.UserAuditResult()  # noqa: E501
        if include_optional :
            return UserAuditResult(
                actions = [
                    vrt_lss_account.models.account_action.AccountAction(
                        time = '2021-05-21T09:30+03:00', 
                        service = 'LASTMILE', 
                        method = 'PLAN', 
                        detail = vrt_lss_account.models.user_action_detail.UserActionDetail(
                            tracedata = vrt_lss_account.models.trace_data.TraceData(
                                code = 'client_server_service_time_uuid', 
                                client = 'client_name', 
                                server = 'server_name', 
                                time = '2021-02-21T09:30+03:00', ), 
                            points_count = 1500, ), )
                    ], 
                statistics = vrt_lss_account.models.audit_stats.AuditStats(
                    overall = vrt_lss_account.models.detailed_audit_stats.DetailedAuditStats(
                        total = 1, ), 
                    filter = vrt_lss_account.models.detailed_audit_stats.DetailedAuditStats(
                        total = 1, ), )
            )
        else :
            return UserAuditResult(
        )

    def testUserAuditResult(self):
        """Test UserAuditResult"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
